XeNTaX • View topic - Help Needed (Hex2Obj) Battlefield 4

Login Register | FAQ Search

| It is currently Mon Feb 01, 2016 1:30 pm

View unanswered posts | View active topics

All times are UTC + 1 hour

### Forum rules

Please click here to view the forum rules

## Help Needed (Hex2Obj) Battlefield 4

| [ 6 posts ] |

Author | Message
--- | ---
iTzCorky |
Post subject: Help Needed (Hex2Obj) Battlefield 4 Posted: Wed Jun 11, 2014 11:28 am
ultra-n00b
Joined: Wed Jun 11, 2014 12:56 am Posts: 4 Has thanked: 0 time Have thanks: 0 time |
Hello everyone im new around here so don't be to harsh on me. I am trying to learn a new skill and it seems to be impossible lol. I was reading the tutorial on Hex2Obj and was trying to use it for Battlefield 4 but more specifically on a character. I have the .mesh and .chunk files for it and it would make my day if someone could help me understand how this works exactly specifically in the Hex Editor, in this tutorial for Hex2Obj it talked about how to search for patterns and that was where I got lost. I am not sure if I can post the .mesh and .chunk file for this so I won't until I know I am allowed. Any tips would be great
Top |

shakotay2 |
Post subject: Re: Help Needed (Hex2Obj) Battlefield 4 Posted: Wed Jun 11, 2014 12:07 pm
M-M-M-Monster veteran
Joined: Fri Apr 20, 2012 9:24 am Posts: 1355 Has thanked: 125 times Have thanks: 470 times |
the hex2obj tutorial is for simple formats only. iirc the BF4 models are stored in *.chunk files and use half floats which are a little bit harder to identify than floats in a hexeditor. Are you capable to identify floats? If "no", you should start with the simple example in the hex2obj tutorial (tut button). use forum search, read here for example: viewtopic.php?f=16&t=10966&hilit=battlefield (when I wrote "easy" it was addressed to luxor who has much experience with data formats, for beginners this chunk format is hard to solve) dainazinas made a maxscript to import chunk files, should be somewhere here: viewtopic.php?f=16&t=11300 _________________ Extracting simple models: http://forum.xentax.com/viewtopic.php?f=29&t=10894 Hail to the mighty god of hex reversing! "We are Microsoft. You will be assimilated. Resistance is Futile."
Top |

iTzCorky |
Post subject: Re: Help Needed (Hex2Obj) Battlefield 4 Posted: Wed Jun 11, 2014 12:31 pm
ultra-n00b
Joined: Wed Jun 11, 2014 12:56 am Posts: 4 Has thanked: 0 time Have thanks: 0 time |
shakotay2 wrote: the hex2obj tutorial is for simple formats only. iirc the BF4 models are stored in *.chunk files and use half floats which are a little bit harder to identify than floats in a hexeditor. Are you capable to identify floats? If "no", you should start with the simple example in the hex2obj tutorial (tut button). use forum search, read here for example: viewtopic.php?f=16&t=10966&hilit=battlefield (when I wrote "easy" it was addressed to luxor who has much experience with data formats, for beginners this chunk format is hard to solve) dainazinas made a maxscript to import chunk files, should be somewhere here: viewtopic.php?f=16&t=11300 Hey thanks for the reply and for identifying them I would say no XD but I would love to learn. I have a few questions though if you don't mind. When looking through the hex of the .chunk what exactly am I looking for? In the tutorial you say the pattern but I am so lost lol. Also would it be possible for me to post up the .chunk file for you to look at? I don't want a straight forward answer but a point in the right direction. EDIT: Give me a little time to read up on Half Floats before doing anything XD I will post back when I have read through this to get a better understanding of floats and half floats.
Top |

cra0 |
Post subject: Re: Help Needed (Hex2Obj) Battlefield 4 Posted: Wed Jun 11, 2014 3:18 pm
ultra-veteran
Joined: Fri Apr 27, 2012 9:37 am Posts: 417 Has thanked: 28 times Have thanks: 173 times |
why hasn't anyone made tools for bf4 yet? like it's not even hard. If I get into the hardline beta I'll take a look _________________ Devblog
Top |

iTzCorky |
Post subject: Re: Help Needed (Hex2Obj) Battlefield 4 Posted: Wed Jun 11, 2014 5:59 pm
ultra-n00b
Joined: Wed Jun 11, 2014 12:56 am Posts: 4 Has thanked: 0 time Have thanks: 0 time |
cra0 wrote: why hasn't anyone made tools for bf4 yet? like it's not even hard. If I get into the hardline beta I'll take a look There are a few one that comes to mind is it can find the chunk files from the mesh files and it does it for all of them and puts them in folders its a pretty neat tool.
Top |

iTzCorky |
Post subject: Re: Help Needed (Hex2Obj) Battlefield 4 Posted: Sat Jun 14, 2014 4:59 am
ultra-n00b
Joined: Wed Jun 11, 2014 12:56 am Posts: 4 Has thanked: 0 time Have thanks: 0 time |
YAY I can officially say I found the GUID myself in the mesh file even though it took me a long time and a lot of reading I finally figured it out by looking at the data on the left side in Hex Workshop and found it right at the top so next I shall attempt to extract a model myself and I will not ask for help unless I get stuck for the next 5 hours and yes I will be trying this for the next 5 hours or so. But One quick question the rest of the LOD's what are those supposed to be? I have found several LOD in the mesh file. EDIT: Well ummmmmm No idea what I did here but figured it would be funny to throw out there. This was supposed to be a character XD EDIT 2: Okay so I have tried everything to get this going with no luck still. It is the mp recon from Battlefield 4 the headgear and the locations of meshes I found were here, 0x22050, 0x24DC8, 0x25974, 0x28D70, 0x290D0, 0x2FFA0. Any help would be great
Top |

Display posts from previous: Sort by

| [ 6 posts ] |

You can make the ads go away by registering

All times are UTC + 1 hour

#### Who is online
Users browsing this forum: Google [Bot], yiwang and 4 guests

| You cannot post new topics in this forum You cannot reply to topics in this forum You cannot edit your posts in this forum You cannot delete your posts in this forum You cannot post attachments in this forum

Search for: |
Jump to:

Powered by phpBB © 2000, 2002, 2005, 2007 phpBB Group

website analysis software